@@ -575,49 +575,49 @@ sub get {
 					off => "Kephra::Document::get_readonly() eq 'off';",
 				},
 				syntaxmode => {
-					none => "Kephra::Document::SyntaxMode::get() eq 'none';",
-					ada => "Kephra::Document::SyntaxMode::get() eq 'ada';",
-					as => "Kephra::Document::SyntaxMode::get() eq 'as';",
-					asm => "Kephra::Document::SyntaxMode::get() eq 'asm';",
-					ave => "Kephra::Document::SyntaxMode::get() eq 'ave';",
-					baan => "Kephra::Document::SyntaxMode::get() eq 'baan';",
-					batch => "Kephra::Document::SyntaxMode::get() eq 'batch';",
-					c => "Kephra::Document::SyntaxMode::get() eq 'cpp';",
-					conf => "Kephra::Document::SyntaxMode::get() eq 'conf';",
-					context => "Kephra::Document::SyntaxMode::get() eq 'context';",
-					cs => "Kephra::Document::SyntaxMode::get() eq 'cs';",
-					css => "Kephra::Document::SyntaxMode::get() eq 'css';",
-					diff => "Kephra::Document::SyntaxMode::get() eq 'diff';",
-					eiffel => "Kephra::Document::SyntaxMode::get() eq 'eiffel';",
-					err => "Kephra::Document::SyntaxMode::get() eq 'err';",
-					forth => "Kephra::Document::SyntaxMode::get() eq 'forth';",
-					fortran => "Kephra::Document::SyntaxMode::get() eq 'fortran';",
-					html => "Kephra::Document::SyntaxMode::get() eq 'html';",
-					idl => "Kephra::Document::SyntaxMode::get() eq 'idl';",
-					java => "Kephra::Document::SyntaxMode::get() eq 'java';",
-					js => "Kephra::Document::SyntaxMode::get() eq 'js';",
-					latex => "Kephra::Document::SyntaxMode::get() eq 'latex';",
-					lisp => "Kephra::Document::SyntaxMode::get() eq 'lisp';",
-					lua => "Kephra::Document::SyntaxMode::get() eq 'lua';",
-					make => "Kephra::Document::SyntaxMode::get() eq 'make';",
-					matlab => "Kephra::Document::SyntaxMode::get() eq 'matlab';",
-					nsis => "Kephra::Document::SyntaxMode::get() eq 'nsis';",
-					pascal => "Kephra::Document::SyntaxMode::get() eq 'pascal';",
-					perl => "Kephra::Document::SyntaxMode::get() eq 'perl';",
-					php => "Kephra::Document::SyntaxMode::get() eq 'php';",
-					property => "Kephra::Document::SyntaxMode::get() eq 'property';",
-					ps => "Kephra::Document::SyntaxMode::get() eq 'ps';",
-					python => "Kephra::Document::SyntaxMode::get() eq 'python';",
-					ruby => "Kephra::Document::SyntaxMode::get() eq 'ruby';",
-					scheme => "Kephra::Document::SyntaxMode::get() eq 'scheme';",
-					sh => "Kephra::Document::SyntaxMode::get() eq 'sh';",
-					sql => "Kephra::Document::SyntaxMode::get() eq 'sql';",
-					tcl => "Kephra::Document::SyntaxMode::get() eq 'tcl';",
-					tex => "Kephra::Document::SyntaxMode::get() eq 'tex';",
-					vb => "Kephra::Document::SyntaxMode::get() eq 'vb';",
-					vbs => "Kephra::Document::SyntaxMode::get() eq 'vbs';",
-					xml => "Kephra::Document::SyntaxMode::get() eq 'xml';",
-					yaml => "Kephra::Document::SyntaxMode::get() eq 'yaml';",
+					none => "Kephra::Document::SyntaxMode::_ID() eq 'none';",
+					ada => "Kephra::Document::SyntaxMode::_ID() eq 'ada';",
+					as => "Kephra::Document::SyntaxMode::_ID() eq 'as';",
+					asm => "Kephra::Document::SyntaxMode::_ID() eq 'asm';",
+					ave => "Kephra::Document::SyntaxMode::_ID() eq 'ave';",
+					baan => "Kephra::Document::SyntaxMode::_ID() eq 'baan';",
+					batch => "Kephra::Document::SyntaxMode::_ID() eq 'batch';",
+					c => "Kephra::Document::SyntaxMode::_ID() eq 'cpp';",
+					conf => "Kephra::Document::SyntaxMode::_ID() eq 'conf';",
+					context => "Kephra::Document::SyntaxMode::_ID() eq 'context';",
+					cs => "Kephra::Document::SyntaxMode::_ID() eq 'cs';",
+					css => "Kephra::Document::SyntaxMode::_ID() eq 'css';",
+					diff => "Kephra::Document::SyntaxMode::_ID() eq 'diff';",
+					eiffel => "Kephra::Document::SyntaxMode::_ID() eq 'eiffel';",
+					err => "Kephra::Document::SyntaxMode::_ID() eq 'err';",
+					forth => "Kephra::Document::SyntaxMode::_ID() eq 'forth';",
+					fortran => "Kephra::Document::SyntaxMode::_ID() eq 'fortran';",
+					html => "Kephra::Document::SyntaxMode::_ID() eq 'html';",
+					idl => "Kephra::Document::SyntaxMode::_ID() eq 'idl';",
+					java => "Kephra::Document::SyntaxMode::_ID() eq 'java';",
+					js => "Kephra::Document::SyntaxMode::_ID() eq 'js';",
+					latex => "Kephra::Document::SyntaxMode::_ID() eq 'latex';",
+					lisp => "Kephra::Document::SyntaxMode::_ID() eq 'lisp';",
+					lua => "Kephra::Document::SyntaxMode::_ID() eq 'lua';",
+					make => "Kephra::Document::SyntaxMode::_ID() eq 'make';",
+					matlab => "Kephra::Document::SyntaxMode::_ID() eq 'matlab';",
+					nsis => "Kephra::Document::SyntaxMode::_ID() eq 'nsis';",
+					pascal => "Kephra::Document::SyntaxMode::_ID() eq 'pascal';",
+					perl => "Kephra::Document::SyntaxMode::_ID() eq 'perl';",
+					php => "Kephra::Document::SyntaxMode::_ID() eq 'php';",
+					property => "Kephra::Document::SyntaxMode::_ID() eq 'property';",
+					ps => "Kephra::Document::SyntaxMode::_ID() eq 'ps';",
+					python => "Kephra::Document::SyntaxMode::_ID() eq 'python';",
+					ruby => "Kephra::Document::SyntaxMode::_ID() eq 'ruby';",
+					scheme => "Kephra::Document::SyntaxMode::_ID() eq 'scheme';",
+					sh => "Kephra::Document::SyntaxMode::_ID() eq 'sh';",
+					sql => "Kephra::Document::SyntaxMode::_ID() eq 'sql';",
+					tcl => "Kephra::Document::SyntaxMode::_ID() eq 'tcl';",
+					tex => "Kephra::Document::SyntaxMode::_ID() eq 'tex';",
+					vb => "Kephra::Document::SyntaxMode::_ID() eq 'vb';",
+					vbs => "Kephra::Document::SyntaxMode::_ID() eq 'vbs';",
+					xml => "Kephra::Document::SyntaxMode::_ID() eq 'xml';",
+					yaml => "Kephra::Document::SyntaxMode::_ID() eq 'yaml';",
 				},
 				tabs => {
 					soft => 'Kephra::Document::get_tab_mode() == 0',
